#ifndef NOWLISTENINGPLUGINSYSTEM_H
#define NOWLISTENINGPLUGINSYSTEM_H

#include "qutim/plugininterface.h"
#include "qutim/jabber.h"
#include "settingsui.h"
#include "trackmetainfo.h"
#include "winampdatagetter.h"

#ifndef Q_WS_WIN

#include "mprisdatagetter.h"
#include "mpddatagetter.h"
#include "amarok14datagetter.h"

#endif

#include <QObject>
#include <QTextCodec>
#include <QDebug>
#include <QVariant>
#include <QString>
#include <QHash>
#include <QAction>

using namespace qutim_sdk_0_2;

class NowListeningPluginSystem : public QObject, SimplePluginInterface, EventHandler{

Q_OBJECT
Q_INTERFACES ( qutim_sdk_0_2::PluginInterface )

public:

    bool init ( PluginSystemInterface *plugin_system );
    void release();
    void processEvent ( Event &event );
    QWidget *settingsWidget();
    void setProfileName ( const QString &profile_name );
    QString name();
    QString description();
    QString type();
    QIcon* icon();
    void removeSettingsWidget();
    void saveSettings();
    QAction* m_manage_plugin;

private:
    QHash<QString,int>* m_current_icq_status;
    qint16 m_event_init;
    qint16 m_event_online;
    qint16 m_event_jabber;
    qint16 m_event_icq;
    qint16 m_event_mrim_status_set;
    qint16 m_event_mrim_status_set_text;
    qint16 m_event_mrim_status_changed;
    PluginSystemInterface* m_plugin_system;
    QIcon* m_plugin_icon;
    QString m_profile_name;
    SettingsUI* m_settings_form;
    struct IcqAccountSettings{
        QString name;
        int status;
        QString message_mask_1;
        QString message_mask_2;
    };
    struct JabberAccountSettings{
        QString name;
        int status;
        QString message_mask;
    };
    struct MrimAccountSettings{
        QString name;
        int status;
        QString message_mask_1;
        QString message_mask_2;
        int mode;
    };
    struct GlobalSettings{
        int global;
        int icq_status;
        int jabber_status;
        int mrim_status;
        int mrim_mode;
        QString icq_message_mask_1;
        QString icq_message_mask_2;
        QString mrim_message_mask_1;
        QString mrim_message_mask_2;
        QString jabber_message;
    } m_global_settings;
    struct MrimCurrentStatus{
        QString account;
        qint32 status_num;
        QString status_text;
        QString status_title;
        QString status_description;
    };

    struct MPDSettings{
            QVariant hostname;
            int port;
            QVariant password;
    } m_mpd_settings;
    TrackMetaInfo m_current_track;
    QList<IcqAccountSettings> m_icq_account_settings;
    QList<MrimAccountSettings> m_mrim_account_settings;
    QList<JabberAccountSettings> m_jabber_account_settings;
    QList<MrimCurrentStatus> m_mrim_current_statuses;
    QStringList m_accounts;
    bool m_global_mode;
    QString m_player_name;
    int m_timer_period;
    bool m_settings_loaded;
    bool m_plugin_active;
    bool m_is_icq_account_active;
    QTimer* m_icq_status_check_timer;
    WinampDataGetter* winampDataGetter;

    #ifndef Q_WS_WIN

    MPRISDataGetter* mprisDataGetter;
    MPDDataGetter* mpdDataGetter;
    Amarok14DataGetter* amarok14DataGetter;

    #endif

    void loadSettings();
    void setIcqXStatus(int account_index);
    void setMrimXStatus(int account_index);
    void sendJabberTune(int account_index);
    int activatePlugin();
    void deactivatePlugin();
    void setStatuses();
    void writeCurrentMrimStatus (QString, qint32, QString, QString, QString);
    int getMrimAccountIndexInList (QString);
    bool isWindowsPlayer(QString player);
    void setEmptyStatuses();

private slots:

    void trackChanged(TrackMetaInfo);
    void playingStoppedStatusChanged(bool);
    void getInfoFromWinamp();
    void checkIcqStatuses();
    void managePluginClicked();

signals:


};

#endif // NOWLISTENINGPLUGINSYSTEM_H
