#include "settingsui.h"

#include <QSettings>
#include <QVariant>

SettingsUI::SettingsUI( QWidget * parent, Qt::WFlags f, QString profileName) : QWidget(parent, f){

        m_profile_name = profileName;
        setupUi(this);
        loadSettings();
        comboBox_accounts->addItems(m_accounts);
        comboBox_players->setCurrentIndex(comboBox_players->findText(m_player_name));
        QVariant temp (m_timer_period);
        lineEdit_timer_period->setText(temp.toString());
        if (m_player_name == "MPD"){
            stackedWidget_2->setCurrentWidget(mpd);
            lineEdit_host->setText(m_mpd_settings.hostname.toString());
            QVariant* temp = new QVariant(m_mpd_settings.port);
            lineEdit_port->setText(temp->toString());
            delete temp;
            lineEdit_password->setText(m_mpd_settings.password.toString());
        }
        else stackedWidget_2->setCurrentWidget(empty);
        if (m_accounts.size() == 1){
            m_global_mode = false;
            m_current_account_index = 0;
            comboBox_accounts->setEnabled(false);
            checkBox_for_all->setChecked(false);
            checkBox_for_all->setEnabled(false);
        }
        else{
            checkBox_for_all->setChecked(m_global_mode);
            if (m_global_mode) m_current_account_index = -1;
            else m_current_account_index = 0;
            comboBox_accounts->setEnabled(!m_global_mode);
        }

        connect(comboBox_players, SIGNAL(currentIndexChanged(QString)), SLOT(playerChanged(QString)));
        connect(rb_1_icq, SIGNAL(toggled(bool)), SLOT(setIcqSecondFieldEnabled(bool)));
        connect(rb_2_icq, SIGNAL(toggled(bool)), SLOT(setIcqThirdFieldEnabled(bool)));
        connect(rb_0_icq, SIGNAL(toggled(bool)), SLOT(setIcqAllFieldsDisabled(bool)));
        connect(rb_1_jabber, SIGNAL(toggled(bool)), SLOT(setJabberSecondFieldEnabled(bool)));
        connect(rb_1_mrim, SIGNAL(toggled(bool)), SLOT(setMrimSecondFieldEnabled(bool)));
        connect(rb_2_mrim, SIGNAL(toggled(bool)), SLOT(setMrimThirdFieldEnabled(bool)));
        connect(rb_0_mrim, SIGNAL(toggled(bool)), SLOT(setMrimAllFieldsDisabled(bool)));
        connect(rb_1_icq_2, SIGNAL(toggled(bool)), SLOT(setGlobalIcqSecondFieldEnabled(bool)));
        connect(rb_2_icq_2, SIGNAL(toggled(bool)), SLOT(setGlobalIcqThirdFieldEnabled(bool)));
        connect(rb_0_icq_2, SIGNAL(toggled(bool)), SLOT(setGlobalIcqAllFieldsDisabled(bool)));
        connect(rb_1_jabber_3, SIGNAL(toggled(bool)), SLOT(setGlobalJabberSecondFieldEnabled(bool)));
        connect(rb_1_mrim_3, SIGNAL(toggled(bool)), SLOT(setGlobalMrimSecondFieldEnabled(bool)));
        connect(rb_2_mrim_3, SIGNAL(toggled(bool)), SLOT(setGlobalMrimThirdFieldEnabled(bool)));
        connect(rb_0_mrim_3, SIGNAL(toggled(bool)), SLOT(setGlobalMrimAllFieldsDisabled(bool)));
        connect(comboBox_accounts, SIGNAL(currentIndexChanged(int)), SLOT(accountChanged(int)));
        connect(checkBox_for_all, SIGNAL(clicked()), SLOT(globalModeStatusChanged()));
        connect(startButton, SIGNAL(pressed()), SLOT(changeGlobalStatus()));

        initFormValues();

}

SettingsUI :: ~SettingsUI(){

        disconnect(comboBox_players, SIGNAL(currentIndexChanged(QString)), this, SLOT(playerChanged(QString)));
        disconnect(rb_1_icq, SIGNAL(toggled(bool)), this, SLOT(setIcqSecondFieldEnabled(bool)));
        disconnect(rb_2_icq, SIGNAL(toggled(bool)), this, SLOT(setIcqThirdFieldEnabled(bool)));
        disconnect(rb_0_icq, SIGNAL(toggled(bool)), this, SLOT(setIcqAllFieldsDisabled(bool)));
        disconnect(rb_1_jabber, SIGNAL(toggled(bool)), this, SLOT(setJabberSecondFieldEnabled(bool)));
        disconnect(rb_1_mrim, SIGNAL(toggled(bool)), this, SLOT(setMrimSecondFieldEnabled(bool)));
        disconnect(rb_2_mrim, SIGNAL(toggled(bool)), this, SLOT(setMrimThirdFieldEnabled(bool)));
        disconnect(rb_0_mrim, SIGNAL(toggled(bool)), this, SLOT(setMrimAllFieldsDisabled(bool)));
        disconnect(rb_1_icq_2, SIGNAL(toggled(bool)), this, SLOT(setGlobalIcqSecondFieldEnabled(bool)));
        disconnect(rb_2_icq_2, SIGNAL(toggled(bool)), this, SLOT(setGlobalIcqThirdFieldEnabled(bool)));
        disconnect(rb_0_icq_2, SIGNAL(toggled(bool)), this, SLOT(setGlobalIcqAllFieldsDisabled(bool)));
        disconnect(rb_1_jabber_3, SIGNAL(toggled(bool)), this, SLOT(setGlobalJabberSecondFieldEnabled(bool)));
        disconnect(rb_1_mrim_3, SIGNAL(toggled(bool)), this, SLOT(setGlobalMrimSecondFieldEnabled(bool)));
        disconnect(rb_2_mrim_3, SIGNAL(toggled(bool)), this, SLOT(setGlobalMrimThirdFieldEnabled(bool)));
        disconnect(rb_0_mrim_3, SIGNAL(toggled(bool)), this, SLOT(setGlobalMrimAllFieldsDisabled(bool)));
        disconnect(comboBox_accounts, SIGNAL(currentIndexChanged(int)), this, SLOT(accountChanged(int)));
        disconnect(checkBox_for_all, SIGNAL(clicked()), this, SLOT(globalModeStatusChanged()));
        disconnect(startButton, SIGNAL(pressed()), this, SLOT(changeGlobalStatus()));

}

void SettingsUI :: loadSettings(){

    QSettings* protocol_settings = new QSettings(QSettings::defaultFormat(), QSettings::UserScope, "qutim/qutim."+m_profile_name, "icqsettings");
    QSettings* settings = new QSettings(QSettings::defaultFormat(), QSettings::UserScope, "qutim/qutim."+m_profile_name, "NowListening");
    m_accounts = protocol_settings->value("accounts/list").toStringList();
    for (int i = 0; i < m_accounts.size(); i++){
        IcqAccountSettings* temp = new IcqAccountSettings;
        temp->name = m_accounts[i];
        temp->status = settings->value(temp->name+"/status", 0).toInt();
        temp->message_mask_1 = settings->value(temp->name+"/message_mask_1", "Now playing: %artist - %title").toString();
        temp->message_mask_2 = settings->value(temp->name+"/message_mask_2", "%artist - %title").toString();
        m_icq_account_settings.append(*temp);
        delete temp;
    }
    delete protocol_settings;
    protocol_settings = new QSettings(QSettings::defaultFormat(), QSettings::UserScope, "qutim/qutim."+m_profile_name, "jabbersettings");
    QStringList acc_temp = protocol_settings->value("accounts/list").toStringList();
    m_accounts += acc_temp;
    for (int i = 0; i < acc_temp.size(); i++){
        JabberAccountSettings* temp = new JabberAccountSettings;
        temp->name = acc_temp[i];
        temp->status = settings->value(temp->name+"/status", 0).toInt();
        temp->message_mask = settings->value(temp->name+"/message", "artist title").toString();
        m_jabber_account_settings.append(*temp);
        delete temp;
    }
    delete protocol_settings;
    protocol_settings = new QSettings(QSettings::defaultFormat(), QSettings::UserScope, "qutim/qutim."+m_profile_name, "mrimsettings");
    acc_temp.clear();
    acc_temp = protocol_settings->value("accounts/list").toStringList();
    m_accounts += acc_temp;
    for (int i = 0; i < acc_temp.size(); i++){
        MrimAccountSettings* temp = new MrimAccountSettings;
        temp->name = acc_temp[i];
        temp->status = settings->value(temp->name+"/status", 0).toInt();
        temp->mode = settings->value(temp->name+"/mode", 2).toInt();
        temp->message_mask_1 = settings->value(temp->name+"/message_mask_1", "Now playing: %artist - %title").toString();
        temp->message_mask_2 = settings->value(temp->name+"/message_mask_2", "%artist - %title").toString();
        m_mrim_account_settings.append(*temp);
        delete temp;
    }
    delete protocol_settings;

    m_global_settings.global = settings->value("Global/global", 0).toInt();
    m_global_settings.icq_status = settings->value("Global/icq_status", 0).toInt();
    m_global_settings.mrim_status = settings->value("Global/mrim_status", 0).toInt();
    m_global_settings.jabber_status = settings->value("Global/jabber_status", 0).toInt();
    m_global_settings.mrim_mode = settings->value("Global/mrim_mode", 0).toInt();
    m_global_settings.icq_message_mask_1 = settings->value("Global/icq_message_mask_1", "Now playing: %artist - %title").toString();
    m_global_settings.icq_message_mask_2 = settings->value("Global/icq_message_mask_2", "%artist - %title").toString();
    m_global_settings.mrim_message_mask_1 = settings->value("Global/mrim_message_mask_1", "Now playing: %artist - %title").toString();
    m_global_settings.mrim_message_mask_2 = settings->value("Global/mrim_message_mask_2", "%artist - %title").toString();
    m_global_settings.jabber_message = settings->value("Global/jabber_message", "artist title").toString();

    m_global_mode = settings->value("Main/global_mode", true).toBool();
    m_player_name = settings->value("Main/player", "Amarok 2").toString();
    m_timer_period = settings->value("Main/timer_period", 5).toInt();
    m_mpd_settings.hostname = settings->value("MPD/hostname", "127.0.0.1");
    m_mpd_settings.port = settings->value("MPD/port", "6600").toInt();
    m_mpd_settings.password = settings->value("MPD/pass", "");


    delete settings;

}

void SettingsUI :: saveSettings(){

    accountChanged(m_current_account_index);

    QSettings* settings = new QSettings(QSettings::defaultFormat(), QSettings::UserScope, "qutim/qutim."+m_profile_name, "NowListening");

    settings->setValue("Main/global_mode", m_global_mode);
    settings->setValue("Main/player", comboBox_players->currentText());
    settings->setValue("Main/timer_period", lineEdit_timer_period->text());

    settings->setValue("MPD/hostname", lineEdit_host->text());
    settings->setValue("MPD/port", lineEdit_port->text());
    settings->setValue("MPD/pass", lineEdit_password->text());

    settings->setValue("Global/global", m_global_settings.global);
    settings->setValue("Global/icq_status", m_global_settings.icq_status);
    settings->setValue("Global/jabber_status", m_global_settings.jabber_status);
    settings->setValue("Global/mrim_status", m_global_settings.mrim_status);
    settings->setValue("Global/mrim_mode", m_global_settings.mrim_mode);
    settings->setValue("Global/icq_message_mask_1", m_global_settings.icq_message_mask_1);
    settings->setValue("Global/icq_message_mask_2", m_global_settings.icq_message_mask_2);
    settings->setValue("Global/mrim_message_mask_1", m_global_settings.mrim_message_mask_1);
    settings->setValue("Global/mrim_message_mask_2", m_global_settings.mrim_message_mask_2);
    settings->setValue("Global/jabber_message", m_global_settings.jabber_message);

    if (m_icq_account_settings.size()){

        for ( int i = 0; i < m_icq_account_settings.size(); i++ ){

            settings->setValue( m_icq_account_settings[i].name+"/status", m_icq_account_settings[i].status );
            settings->setValue( m_icq_account_settings[i].name+"/message_mask_1", m_icq_account_settings[i].message_mask_1 );
            settings->setValue( m_icq_account_settings[i].name+"/message_mask_2", m_icq_account_settings[i].message_mask_2 );

        }

    }

    if (m_mrim_account_settings.size()){

        for ( int i = 0; i < m_mrim_account_settings.size(); i++ ){

            settings->setValue( m_mrim_account_settings[i].name+"/status", m_mrim_account_settings[i].status );
            settings->setValue( m_mrim_account_settings[i].name+"/mode", m_mrim_account_settings[i].mode );
            settings->setValue( m_mrim_account_settings[i].name+"/message_mask_1", m_mrim_account_settings[i].message_mask_1 );
            settings->setValue( m_mrim_account_settings[i].name+"/message_mask_2", m_mrim_account_settings[i].message_mask_2 );

        }

    }

    if (m_jabber_account_settings.size()){

        for ( int i = 0; i < m_jabber_account_settings.size(); i++ ){

            settings->setValue( m_jabber_account_settings[i].name+"/status", m_jabber_account_settings[i].status );
            settings->setValue( m_jabber_account_settings[i].name+"/message", m_jabber_account_settings[i].message_mask );

        }

    }

    delete settings;

}

void SettingsUI :: initFormValues(){

    if (!m_global_settings.global) startButton->setText(tr("Start"));
    else startButton->setText(tr("Stop"));

    if ( m_global_mode ) m_current_account_index = -1;
    else m_current_account_index = comboBox_accounts->currentIndex();
// 
    if ( !m_accounts.size() ){

        stackedWidget->setCurrentWidget(no_accounts);
        comboBox_accounts->setEnabled(false);
        checkBox_for_all->setEnabled(false);
        label_3->setEnabled(false);
        comboBox_players->setEnabled(false);

    }
//MRIRM && ICQ && Jabber
    else if ( m_icq_account_settings.size() && m_jabber_account_settings.size() &&
              m_mrim_account_settings.size() && m_current_account_index == -1 ){

            stackedWidget->setCurrentWidget( global );
            tabWidget->setTabEnabled(0, true);
            tabWidget->setTabEnabled(1, true);
            tabWidget->setTabEnabled(2, true);
            tabWidget->setCurrentIndex(0);
            mask_1_icq_2->setText( m_global_settings.icq_message_mask_1 );
            mask_2_icq_2->setText( m_global_settings.icq_message_mask_2 );
            mask_1_jabber_3->setText( m_global_settings.jabber_message );
            mask_1_mrim_3->setText( m_global_settings.mrim_message_mask_1 );
            mask_2_mrim_3->setText( m_global_settings.mrim_message_mask_2 );

                if ( !m_global_settings.icq_status ){
                    rb_0_icq_2->setChecked(true);
                }

                if ( !m_global_settings.jabber_status ){

                    rb_0_jabber_3->setChecked(true);

                }

                if ( !m_global_settings.mrim_status ){
                    rb_0_mrim_3->setChecked(true);
                }

                if ( m_global_settings.icq_status == 1){

                    rb_1_icq_2->setChecked(true);

                }

                if ( m_global_settings.icq_status == 2){

                    rb_2_icq_2->setChecked(true);

                }

                if ( m_global_settings.mrim_status == 1 ){

                    rb_1_mrim_3->setChecked(true);

                }

                if ( m_global_settings.mrim_status == 2 ){

                    rb_2_mrim_3->setChecked(true);

                }

                if ( !m_global_settings.mrim_mode ){

                    rb_5->setChecked(true);

                }
                else {

                    rb_6->setChecked(true);

                }

                if ( m_global_settings.jabber_status ){

                    rb_1_jabber_3->setChecked(true);

                }

    }

    //ICQ && Jabber
    else if ( m_icq_account_settings.size() && m_jabber_account_settings.size()
              && !m_mrim_account_settings.size()){

        stackedWidget->setCurrentWidget( global );
        tabWidget->setTabEnabled(2, false);
        tabWidget->setTabEnabled(0, true);
        tabWidget->setTabEnabled(1, true);
        tabWidget->setCurrentIndex(0);

        mask_1_icq_2->setText( m_global_settings.icq_message_mask_1 );
        mask_2_icq_2->setText( m_global_settings.icq_message_mask_2 );
        mask_1_jabber_3->setText( m_global_settings.jabber_message );

            if ( !m_global_settings.icq_status ){
                rb_0_icq_2->setChecked(true);
            }

            if ( !m_global_settings.jabber_status ){

                rb_0_jabber_3->setChecked(true);

            }

            if ( m_global_settings.icq_status == 1){

                rb_1_icq_2->setChecked(true);

            }

            if ( m_global_settings.icq_status == 2){

                rb_2_icq_2->setChecked(true);

            }

            if ( m_global_settings.jabber_status ){

                rb_1_jabber_3->setChecked(true);

            }
    }

    //ICQ && MRIM
    else if ( m_icq_account_settings.size() && !m_jabber_account_settings.size()
        && m_mrim_account_settings.size()){

        stackedWidget->setCurrentWidget( global );
        tabWidget->setTabEnabled(0, true);
        tabWidget->setTabEnabled(1, false);
        tabWidget->setTabEnabled(2, true);
        tabWidget->setCurrentIndex(0);

        mask_1_icq_2->setText( m_global_settings.icq_message_mask_1 );
        mask_2_icq_2->setText( m_global_settings.icq_message_mask_2 );
        mask_1_mrim_3->setText( m_global_settings.mrim_message_mask_1 );
        mask_2_mrim_3->setText( m_global_settings.mrim_message_mask_2 );

            if ( !m_global_settings.icq_status ){
                rb_0_icq_2->setChecked(true);
            }

            if ( !m_global_settings.mrim_status ){
                rb_0_mrim_3->setChecked(true);
            }

            if ( m_global_settings.icq_status == 1){

                rb_1_icq_2->setChecked(true);

            }

            if ( m_global_settings.icq_status == 2){

                rb_2_icq_2->setChecked(true);

            }

            if ( m_global_settings.mrim_status == 1 ){

                rb_1_mrim_3->setChecked(true);

            }

            if ( m_global_settings.mrim_status == 2 ){

                rb_2_mrim_3->setChecked(true);

            }

            if ( !m_global_settings.mrim_mode ){

                rb_5->setChecked(true);

            }
            else {

                rb_6->setChecked(true);

            }

    }

    //MRIM && Jabber
    else if ( !m_icq_account_settings.size() && m_jabber_account_settings.size()
        && m_mrim_account_settings.size()){

        stackedWidget->setCurrentWidget( global );
        tabWidget->setTabEnabled(0, false);
        tabWidget->setTabEnabled(1, true);
        tabWidget->setTabEnabled(2, true);
        tabWidget->setCurrentIndex(1);

        mask_1_jabber_3->setText( m_global_settings.jabber_message );
        mask_1_mrim_3->setText( m_global_settings.mrim_message_mask_1 );
        mask_2_mrim_3->setText( m_global_settings.mrim_message_mask_2 );

            if ( !m_global_settings.jabber_status ){

                rb_0_jabber_3->setChecked(true);

            }

            if ( !m_global_settings.mrim_status ){
                rb_0_mrim_3->setChecked(true);
            }


            if ( m_global_settings.jabber_status ){

                rb_1_jabber_3->setChecked(true);

            }

            if ( m_global_settings.mrim_status == 1 ){

                rb_1_mrim_3->setChecked(true);

            }

            if ( m_global_settings.mrim_status == 2 ){

                rb_2_mrim_3->setChecked(true);

            }

            if ( !m_global_settings.mrim_mode ){

                rb_5->setChecked(true);

            }
            else {

                rb_6->setChecked(true);

            }

    }

//ICQ
    else if ( m_icq_account_settings.size() && !m_mrim_account_settings.size() &&
              !m_jabber_account_settings.size() && m_current_account_index == -1 ){

            stackedWidget->setCurrentWidget( icq_only );
            mask_1_icq->setText( m_global_settings.icq_message_mask_1 );
            mask_2_icq->setText( m_global_settings.icq_message_mask_2 );
            if ( !m_global_settings.icq_status ){

                rb_0_icq->setChecked( true );

            }
            else if ( m_global_settings.icq_status == 1 ){

                rb_1_icq->setChecked( true );

            }
            else if ( m_global_settings.icq_status == 2 ){

                rb_2_icq->setChecked( true );

            }

    }

    //Jabber
    else if ( m_jabber_account_settings.size() &&
              !m_icq_account_settings.size() && !m_mrim_account_settings.size() &&
              m_current_account_index == -1 ){

            stackedWidget->setCurrentWidget( jabber_only );
            mask_1_jabber->setText( m_global_settings.jabber_message );
            if ( !m_global_settings.jabber_status ){

                rb_0_jabber->setChecked( true );

            }
            else{

                rb_1_jabber->setChecked( true );

            }

    }

    //MRIM
    else if ( m_mrim_account_settings.size() && !m_icq_account_settings.size()
        && !m_jabber_account_settings.size() && m_current_account_index == -1){

        stackedWidget->setCurrentWidget(mrim_only);
        mask_1_mrim->setText( m_global_settings.mrim_message_mask_1 );
        mask_2_mrim->setText( m_global_settings.mrim_message_mask_2 );
        if ( !m_global_settings.mrim_status ){
            rb_0_mrim_3->setChecked(true);
        }
        if ( m_global_settings.mrim_status == 1 ){

            rb_1_mrim->setChecked(true);

        }

        if ( m_global_settings.mrim_status == 2 ){

            rb_2_mrim->setChecked(true);

        }

        if ( !m_global_settings.mrim_mode ){

            rb_1->setChecked(true);

        }
        else {

            rb_2->setChecked(true);

        }
    }
//Jabber Only
    if ( m_current_account_index != -1 && comboBox_accounts->currentText().contains( "@" ) &&
         !(comboBox_accounts->currentText().contains( "@mail.ru" ) ||
           comboBox_accounts->currentText().contains( "@list.ru" ) ||
           comboBox_accounts->currentText().contains( "@inbox.ru" ) ||
           comboBox_accounts->currentText().contains( "@bk.ru" ))){

            int index = getIndexByName("jabber", comboBox_accounts->currentText());
            stackedWidget->setCurrentWidget( jabber_only );
            mask_1_jabber->setText( m_jabber_account_settings[index].message_mask);
            if ( !m_jabber_account_settings[index].status ){

                rb_0_jabber->setChecked( true );

            }
            else{

                rb_1_jabber->setChecked( true );

            }

    }
//MRIM Only
    else if ( m_current_account_index != -1 && (comboBox_accounts->currentText().contains( "@mail.ru" ) ||
           comboBox_accounts->currentText().contains( "@list.ru" ) ||
           comboBox_accounts->currentText().contains( "@inbox.ru" ) ||
           comboBox_accounts->currentText().contains( "@bk.ru" ))){

            int index = getIndexByName("mrim", comboBox_accounts->currentText());
            stackedWidget->setCurrentWidget( mrim_only );
            mask_1_mrim->setText( m_mrim_account_settings[index].message_mask_1 );
            mask_2_mrim->setText( m_mrim_account_settings[index].message_mask_2 );
            if ( !m_mrim_account_settings[index].status ){

                rb_0_mrim->setChecked( true );

            }
            else if ( m_mrim_account_settings[index].status == 1 ){

                rb_1_mrim->setChecked( true );

            }
            else if ( m_mrim_account_settings[index].status == 2 ){

                rb_2_mrim->setChecked( true );

            }
            if ( !m_mrim_account_settings[index].mode ){
                rb_1->setChecked(true);
            }
            else {
                rb_2->setChecked(true);
            }

    }
    //ICQ Only
    else if ( m_current_account_index != -1 ){

            int index = getIndexByName("icq", comboBox_accounts->currentText());
            stackedWidget->setCurrentWidget( icq_only );
            mask_1_icq->setText( m_icq_account_settings[index].message_mask_1 );
            mask_2_icq->setText( m_icq_account_settings[index].message_mask_2 );
            if ( !m_icq_account_settings[index].status ){

                rb_0_icq->setChecked( true );

            }
            else if ( m_icq_account_settings[index].status == 1 ){

                rb_1_icq->setChecked( true );

            }
            else if ( m_icq_account_settings[index].status == 2 ){

                rb_2_icq->setChecked( true );

            }

    }

}

void SettingsUI :: setIcqSecondFieldEnabled(bool checked){
    if (checked){
        mask_1_icq->setEnabled(true);

    }
    else{
        setIcqSecondFieldDisabled();
    }
}

void SettingsUI :: setIcqSecondFieldDisabled(){
     mask_1_icq->setEnabled(false);
}

void SettingsUI :: setIcqThirdFieldEnabled(bool checked){
    if (checked){
        mask_2_icq->setEnabled(true);
    }else{
        setIcqThirdFieldDisabled();
    }
}

void SettingsUI :: setIcqThirdFieldDisabled(){
    mask_2_icq->setEnabled(false);
}

void SettingsUI :: setIcqAllFieldsDisabled(bool checked){
    if (checked){
        setIcqSecondFieldDisabled();
        setIcqThirdFieldDisabled();
    }
}

void SettingsUI :: setJabberSecondFieldEnabled(bool checked){

    if (checked){
        label_1_jabber->setEnabled(true);
        mask_1_jabber->setEnabled(true);

    }
    else{
        setJabberSecondFieldDisabled();
    }

}

void SettingsUI :: setJabberSecondFieldDisabled(){

    label_1_jabber->setEnabled(false);
    mask_1_jabber->setEnabled(false);

}

void SettingsUI :: setMrimSecondFieldEnabled(bool checked){
    if (checked){
        mask_1_mrim->setEnabled(true);
    }
    else{
        setMrimSecondFieldDisabled();
    }
}

void SettingsUI :: setMrimSecondFieldDisabled(){
    mask_1_mrim->setEnabled(false);
}

void SettingsUI :: setMrimThirdFieldEnabled(bool checked){
    if (checked){
        mask_2_mrim->setEnabled(true);
    }else{
        setMrimThirdFieldDisabled();
    }
}

void SettingsUI :: setMrimThirdFieldDisabled(){
    mask_2_mrim->setEnabled(false);
}

void SettingsUI :: setMrimAllFieldsDisabled(bool checked){
    if (checked){
        setMrimSecondFieldDisabled();
        setMrimThirdFieldDisabled();
    }
}

void SettingsUI :: setGlobalIcqSecondFieldEnabled(bool checked){
    if (checked){
        mask_1_icq_2->setEnabled(true);

    }
    else{
        setGlobalIcqSecondFieldDisabled();
    }
}

void SettingsUI :: setGlobalIcqSecondFieldDisabled(){
    mask_1_icq_2->setEnabled(false);
}

void SettingsUI :: setGlobalIcqThirdFieldEnabled(bool checked){
    if (checked){
        mask_2_icq_2->setEnabled(true);
    }else{
        setGlobalIcqThirdFieldDisabled();
    }
}

void SettingsUI :: setGlobalIcqThirdFieldDisabled(){
    mask_2_icq_2->setEnabled(false);
}

void SettingsUI :: setGlobalIcqAllFieldsDisabled(bool checked){
    if (checked){
        setGlobalIcqSecondFieldDisabled();
        setGlobalIcqThirdFieldDisabled();
    }
}

void SettingsUI :: setGlobalJabberSecondFieldEnabled(bool checked){

    if (checked){
        label_1_jabber_3->setEnabled(true);
        mask_1_jabber_3->setEnabled(true);

    }
    else{
        setGlobalJabberSecondFieldDisabled();
    }

}

void SettingsUI :: setGlobalJabberSecondFieldDisabled(){

    label_1_jabber_3->setEnabled(false);
    mask_1_jabber_3->setEnabled(false);

}

void SettingsUI :: setGlobalMrimSecondFieldEnabled(bool checked){
    if (checked){
        mask_1_mrim_3->setEnabled(true);
    }
    else{
        setGlobalMrimSecondFieldDisabled();
    }
}

void SettingsUI :: setGlobalMrimSecondFieldDisabled(){
    mask_1_mrim_3->setEnabled(false);
}

void SettingsUI :: setGlobalMrimThirdFieldEnabled(bool checked){
    if (checked){
        mask_2_mrim_3->setEnabled(true);
    }else{
        setGlobalMrimThirdFieldDisabled();
    }
}

void SettingsUI :: setGlobalMrimThirdFieldDisabled(){
    mask_2_mrim_3->setEnabled(false);
}

void SettingsUI :: setGlobalMrimAllFieldsDisabled(bool checked){
    if (checked){
        setGlobalMrimSecondFieldDisabled();
        setGlobalMrimThirdFieldDisabled();
    }
}

//    
void SettingsUI :: accountChanged(int index){

    if ( stackedWidget->currentIndex() ==  1){

        m_global_settings.icq_message_mask_1 = mask_1_icq_2->text();
        m_global_settings.icq_message_mask_2 = mask_2_icq_2->text();
        m_global_settings.jabber_message = mask_1_jabber_3->text();
        m_global_settings.mrim_message_mask_1 = mask_1_mrim_3->text();
        m_global_settings.mrim_message_mask_2 = mask_2_mrim_3->text();

        if ( rb_0_icq_2->isChecked() ) m_global_settings.icq_status = 0;
        if ( rb_1_icq_2->isChecked() ) m_global_settings.icq_status = 1;
        if ( rb_2_icq_2->isChecked() ) m_global_settings.icq_status = 2;
        if ( rb_0_jabber_3->isChecked() ) m_global_settings.jabber_status = 0;
        if ( rb_1_jabber_3->isChecked() ) m_global_settings.jabber_status = 1;
        if ( rb_0_mrim_3->isChecked() ) m_global_settings.mrim_status = 0;
        if ( rb_1_mrim_3->isChecked() ) m_global_settings.mrim_status = 1;
        if ( rb_2_mrim_3->isChecked() ) m_global_settings.mrim_status = 2;
        if ( rb_5->isChecked() ) m_global_settings.mrim_mode = 0;
        if ( rb_6->isChecked() ) m_global_settings.mrim_mode = 1;

    }

    else if (stackedWidget->currentIndex() == 2 && m_current_account_index == -1){

        m_global_settings.icq_message_mask_1 = mask_1_icq->text();
        m_global_settings.icq_message_mask_2 = mask_2_icq->text();
        m_global_settings.jabber_message = "artist title";
        m_global_settings.jabber_status = 0;
        m_global_settings.mrim_message_mask_1 = "Now playing: %artist - %title";
        m_global_settings.mrim_message_mask_2 = "%artist - %title";
        m_global_settings.mrim_status = 0;
        m_global_settings.mrim_mode = 1;
        if (rb_0_icq->isChecked()) m_global_settings.icq_status = 0;
        else if (rb_1_icq->isChecked()) m_global_settings.icq_status = 1;
        else m_global_settings.icq_status = 2;

    }

    else if (stackedWidget->currentIndex() == 2 && m_current_account_index != -1){

            index = getIndexByName("icq", comboBox_accounts->itemText(m_current_account_index));
            m_icq_account_settings[index].message_mask_1 = mask_1_icq->text();
            m_icq_account_settings[index].message_mask_2 = mask_2_icq->text();
            if (rb_0_icq->isChecked()) m_icq_account_settings[index].status = 0;
            else if (rb_1_icq->isChecked()) m_icq_account_settings[index].status = 1;
            else  m_icq_account_settings[index].status = 2;

    }

    else if ( stackedWidget->currentIndex() == 3 && m_current_account_index == -1 ){

        m_global_settings.mrim_message_mask_1 = mask_1_mrim->text();
        m_global_settings.mrim_message_mask_2 = mask_2_mrim->text();
        if ( rb_0_mrim->isChecked() ) m_global_settings.mrim_status = 0;
        if ( rb_1_mrim->isChecked() ) m_global_settings.mrim_status = 1;
        if ( rb_2_mrim->isChecked() ) m_global_settings.mrim_status = 2;
        if ( rb_1->isChecked() ) m_global_settings.mrim_mode = 0;
        if ( rb_2->isChecked() ) m_global_settings.mrim_mode = 1;
        m_global_settings.icq_message_mask_1 = "Now playing: %artist - %title";
        m_global_settings.icq_message_mask_2 = "%artist - %title";
        m_global_settings.icq_status = 0;
        m_global_settings.jabber_message = "artist title";
        m_global_settings.jabber_status = 0;

    }

    else if ( stackedWidget->currentIndex() == 3 && m_current_account_index != -1){

        index = getIndexByName("mrim", comboBox_accounts->itemText(m_current_account_index));
        m_mrim_account_settings[index].message_mask_1 = mask_1_mrim->text();
        m_mrim_account_settings[index].message_mask_2 = mask_2_mrim->text();
        if ( rb_0_mrim->isChecked() ) m_mrim_account_settings[index].status = 0;
        if ( rb_1_mrim->isChecked() ) m_mrim_account_settings[index].status = 1;
        if ( rb_2_mrim->isChecked() ) m_mrim_account_settings[index].status = 2;
        if ( rb_1->isChecked() ) m_mrim_account_settings[index].mode = 0;
        if ( rb_2->isChecked() ) m_mrim_account_settings[index].mode = 1;

    }

    else if (stackedWidget->currentIndex() == 4 && m_current_account_index == -1){

        m_global_settings.jabber_message = mask_1_jabber->text();
        m_global_settings.icq_message_mask_1 = "Now playing: %artist - %title";
        m_global_settings.icq_message_mask_2 = "%artist - %title";
        m_global_settings.icq_status = 0;
        m_global_settings.mrim_message_mask_1 = "Now playing: %artist - %title";
        m_global_settings.mrim_message_mask_2 = "%artist - %title";
        m_global_settings.mrim_status = 0;
        m_global_settings.mrim_mode = 1;
        if (rb_0_jabber->isChecked()) m_global_settings.jabber_status = 0;
        else m_global_settings.jabber_status = 1;

    }

    else if (stackedWidget->currentIndex() == 4 && m_current_account_index != -1){

        index = getIndexByName("jabber", comboBox_accounts->itemText(m_current_account_index));
        m_jabber_account_settings[index].message_mask = mask_1_jabber->text();
        if (rb_0_jabber->isChecked()) m_jabber_account_settings[index].status = 0;
        else  m_jabber_account_settings[index].status = 1;

    }



    m_current_account_index = index;
    initFormValues();

}

void SettingsUI :: globalModeStatusChanged(){

    if (checkBox_for_all->isChecked()){

        m_global_mode = true;
        comboBox_accounts->setEnabled(false);
        accountChanged(-1);

    }
    else{

        m_global_mode = false;
        comboBox_accounts->setEnabled(true);
        accountChanged(0);

    }

}

int SettingsUI :: getIndexByName(QString protocol_name, QString account){

    if (protocol_name == "icq"){

        for (int i = 0; i < m_icq_account_settings.size(); i++){

            if ( m_icq_account_settings[i].name == account) return i;

        }

    }

    else if (protocol_name == "jabber"){

        for (int i = 0; i < m_jabber_account_settings.size(); i++){

            if ( m_jabber_account_settings[i].name == account) return i;

        }

    }

    else if ( protocol_name == "mrim" ){

        for (int i = 0; i < m_mrim_account_settings.size(); i++){

            if ( m_mrim_account_settings[i].name == account) return i;

        }

    }

   return 0;

}

void SettingsUI :: playerChanged(QString player){

     if (player == "MPD"){
            stackedWidget_2->setCurrentWidget(mpd);
            lineEdit_host->setText(m_mpd_settings.hostname.toString());
            QVariant* temp = new QVariant(m_mpd_settings.port);
            lineEdit_port->setText(temp->toString());
            delete temp;
            lineEdit_password->setText(m_mpd_settings.password.toString());
        }
        else {
            stackedWidget_2->setCurrentWidget(empty);
            QVariant* temp = new QVariant(lineEdit_host->text());
            m_mpd_settings.hostname = *temp;
            temp = new QVariant(lineEdit_port->text());
            m_mpd_settings.port = temp->toInt();
            temp = new QVariant(lineEdit_password->text());
            m_mpd_settings.password = *temp;
            delete temp;
        }

}

void SettingsUI::changeGlobalStatus(){
    if (!m_global_settings.global) {
        m_global_settings.global = 1;
        startButton->setText(tr("Stop"));
    }

    else {
        m_global_settings.global = 0;
        startButton->setText(tr("Start"));
    }
}
