#include "winampdatagetter.h"
#include <QTextCodec>
#include <QRegExp>
#include <QStringList>
#include <QtDebug>

#ifdef Q_WS_WIN
#include <windows.h>
#endif

WinampDataGetter::WinampDataGetter()
{
    m_current_track.artist = " ";
    m_current_track.title = " ";
}

WinampDataGetter::~WinampDataGetter()
{ }

void WinampDataGetter::updateTrackInfo()
{
#ifdef Q_WS_WIN
    QString title = m_current_track.title;
    QString artist = m_current_track.artist;

    HWND wnd = ::FindWindow(TEXT("Winamp v1.x"),0);

    if (!wnd)
    {
        reset();
        return;
    }
    WCHAR titleBuff[256];
    ::ZeroMemory(titleBuff,256);
    int len = ::GetWindowTextW(wnd,titleBuff,256);

    if (!len)
    {
        reset();
        return;
    }
    QTextCodec* codec = QTextCodec::codecForName("UTF-16");
    QString uniTitle = codec->toUnicode((char*)titleBuff,len*sizeof(WCHAR));
    QRegExp stripRx(".{0,}\\d+[.]\\s(.+)\\s-\\sWinamp");

    if (stripRx.indexIn(uniTitle) >= 0)
    {
        uniTitle = stripRx.cap(1);
        QStringList trackInfoList = uniTitle.split(" - ",QString::SkipEmptyParts);

        if (trackInfoList.count() == 1)
        {
            title = trackInfoList[0];
        }
        else if (trackInfoList.count() > 1)
        {
            artist = trackInfoList[0];
            title = trackInfoList[1];
        }
        submitIfChanged(artist,title);
    }
    else
    {
        reset();
    }
#endif
}

void WinampDataGetter::submitIfChanged(const QString artist, const QString& title)
{
    if (m_current_track.title != title || m_current_track.artist != artist)
    {
        qDebug()<<"Winamp(AIMP): track is changed!";
        m_current_track.title = title;
        m_current_track.artist = artist;
        emit trackChanged();
    }
}

void WinampDataGetter::reset()
{
    submitIfChanged("","");
}

